
## CATO-CLI - mutation.sites.updateStaticHost:
[Click here](https://api.catonetworks.com/documentation/#mutation-updateStaticHost) for documentation on this operation.

### Usage for mutation.sites.updateStaticHost:

`catocli mutation sites updateStaticHost -h`

`catocli mutation sites updateStaticHost <json>`

`catocli mutation sites updateStaticHost "$(cat < updateStaticHost.json)"`

`catocli mutation sites updateStaticHost '{"hostId": "ID", "updateStaticHostInput": {"ip": {"ip": "IPAddress"}, "macAddress": {"macAddress": "String"}, "name": {"name": "String"}}}'`

#### Operation Arguments for mutation.sites.updateStaticHost ####
`accountId` [ID] - (required) N/A 
`hostId` [ID] - (required) N/A 
`updateStaticHostInput` [UpdateStaticHostInput] - (required) N/A 
